module("L_HoneywellTCC_const")

-- Service names
SERVICE_OPMODE = "urn:upnp-org:serviceId:HVAC_UserOperatingMode1"
SERVICE_OPSTATE = "urn:micasaverde-com:serviceId:HVAC_OperatingState1"
SERVICE_SETPOINT = "urn:upnp-org:serviceId:TemperatureSetpoint1"
SERVICE_SETPOINT_HEAT = "urn:upnp-org:serviceId:TemperatureSetpoint1_Heat"
SERVICE_SETPOINT_COOL = "urn:upnp-org:serviceId:TemperatureSetpoint1_Cool"
SERVICE_FAN_OPMODE = "urn:upnp-org:serviceId:HVAC_FanOperatingMode1"
SERVICE_THERMODATA = "urn:honeywell-com:serviceId:ThermostatData1"
SERVICE_TEMPSENSOR = "urn:upnp-org:serviceId:TemperatureSensor1"

-- Status codes
STATUS_OK = 1
STATUS_FAIL = 2
STATUS_REMOTE_FAIL = 3
STATUS_AUTH_FAIL = 4
STATUS_HTTP_FAIL = 5

-- Defaults
DEFAULT_REFRESH_INTERVAL = 300 -- in seconds
DEFAULT_REAUTH_INTERVAL = 60*24 -- in minutes

-- TCC properties
PROP_SETPOINT_BEHAVE = "setpointDefaultBehave"
PROP_REFRESH_INTERVAL = "RefreshInterval"
PROP_REAUTH_INTERVAL = "ReAuthInterval"
PROP_REFRESH_AFTER_CHANGE_INTERVAL = "RefreshAfterChangeInterval"
PROP_USERNAME = "Username" -- used in control panel
PROP_PASSWORD = "Password" -- used in control panel

PROP_COOKIE_REFRESH_TIME = "cookieRefreshTime" -- used in device control panel
PROP_CRED_PASSED = "credPassed"
PROP_CRED_AUTHORIZED = "credAuthorized" -- used in device control panel
PROP_LAST_AUTO_REFRESH = "lastAutoRefresh"
PROP_STATUS_REFRESH_DATETIME = "statusRefreshDateTime" -- used in device control panel
PROP_STATUS_REFRESH_TIME_SUCCESS = "statusRefreshTimeSuccess"
PROP_GET_STATUS = "getStatus" -- used in device control panel
PROP_LOG_CONTROL = "LogEnable"
PROP_LOG_HTTP_CONTROL = "LogHttpEnable"
PROP_TRACE_CONTROL = "TraceEnable"
PROP_VERSION = "Version"
PROP_TYPE = "InterfaceType"

-- THERMODATA properties
PROP_THERMO_UNITS = "ThermostatUnits"

-- OPMODE properties
PROP_MODE_STATUS = "ModeStatus"

--------------------------------------------------------------------------------
-- Get status record
-- {
--   Success,			-- true/false for status
--   Load,			-- obsolete
--
--   FanSwitchPosition,		-- 0=auto, 1=on, 2=circulate, 3=sched
--   HasFan,			-- true/false indicating fan present
--
--   StatusCool,		-- 0=sched, 1=temp hold, 2=perm hold
--   CoolNextPeriod,		-- time of next change in 15 minute increments
--   CoolSetpoint,		-- temperature setpoint
--   SchedCoolSetpoint,		-- 
--
--   StatusHeat,		-- 0=sched, 1=temp hold, 2=perm hold
--   HeatNextPeriod,		-- time of next change in 15 minute increments
--   HeatSetpoint,		-- temperature setpoint
--   SchedHeatSetpoint,		--
--
--   DisplayUnits,		-- "F" or "C"
--   DisplayTemp,		-- Current temperature
--
--   IndoorHumidity,		-- indoor humidity
--   HasIndoorHumidity,		-- true/false indicating humidity valid
--
--   OutdoorHumidity,		-- outdoor humidity
--   HasOutdoorHumidity,	-- true/false indicating humidity valid
--
--   OutdoorTemp,		-- outside temperature
--   HasOutdoorTemp,		-- true/false indicating temp valid
--
--   CanSwitchAuto,		-- true/false has auto
--   SystemSwitchPosition	-- 1=heat, 2=off, 3=cool, 4=auto
-- }

--------------------------------------------------------------------------------
-- Set status record
-- { DeviceID			-- device string
--   SystemSwitch,		-- 2=Off, 1=Heat, 3=Cool, 4=Auto
--   HeatSetpoint,		-- temperature
--   CoolSetpoint,		-- temperature
--   HeatNextPeriod,		-- integer representing a 15 minute period of day.
--                                 0=12:00 AM, 1=12:15, 4 = 1:00 AM etc.
--   CoolNextPeriod,		-- integer representing a 15 minute period of day
--                                 0=12:00 AM, 1=12:15, 4 = 1:00 AM etc.
--   StatusHeat,		-- 1=until next program, 2=permanent, 0=cancel
--   StatusCool,		-- 1=until next program, 2=permanent, 0=cancel
--   FanMode,			-- 2=Circulate, 0=Auto, 1=On, 3=Follow Schedule
-- }

STATUS_DEVICE_ID = "DeviceId"

-- SystemSwitch
--   0 = 
--   1 = HeatOn
--   2 = Off
--   3 = CoolOn
--   4 = AutoChangeOver
SYSTEM_SWITCH = "SystemSwitch"
SYSTEM_SWITCH_HEAT_ID = 1
SYSTEM_SWITCH_HEAT = "HeatOn"
SYSTEM_SWITCH_HEAT1 = "Heat"
SYSTEM_SWITCH_OFF_ID = 2
SYSTEM_SWITCH_OFF = "Off"
SYSTEM_SWITCH_COOL_ID = 3
SYSTEM_SWITCH_COOL = "CoolOn"
SYSTEM_SWITCH_COOL1 = "Cool"
SYSTEM_SWITCH_AUTO_ID = 4
SYSTEM_SWITCH_AUTO = "Auto"
SYSTEM_SWITCH_MAP = {
   [SYSTEM_SWITCH_HEAT] = SYSTEM_SWITCH_HEAT_ID,
   [SYSTEM_SWITCH_COOL] = SYSTEM_SWITCH_COOL_ID,
   [SYSTEM_SWITCH_AUTO] = SYSTEM_SWITCH_AUTO_ID,
   [SYSTEM_SWITCH_OFF] = SYSTEM_SWITCH_OFF_ID,
}
SYSTEM_SWITCH_RMAP = {
   [SYSTEM_SWITCH_HEAT_ID] = SYSTEM_SWITCH_HEAT,
   [SYSTEM_SWITCH_COOL_ID] = SYSTEM_SWITCH_COOL,
   [SYSTEM_SWITCH_AUTO_ID] = SYSTEM_SWITCH_AUTO,
   [SYSTEM_SWITCH_OFF_ID] = SYSTEM_SWITCH_OFF,
}
SYSTEM_SWITCH_MAP1 = {
   [SYSTEM_SWITCH_HEAT1] = SYSTEM_SWITCH_HEAT_ID,
   [SYSTEM_SWITCH_COOL1] = SYSTEM_SWITCH_COOL_ID,
   [SYSTEM_SWITCH_AUTO] = SYSTEM_SWITCH_AUTO_ID,
   [SYSTEM_SWITCH_OFF] = SYSTEM_SWITCH_OFF_ID,
}
SYSTEM_SWITCH_RMAP1 = {
   [SYSTEM_SWITCH_HEAT_ID] = SYSTEM_SWITCH_HEAT1,
   [SYSTEM_SWITCH_COOL_ID] = SYSTEM_SWITCH_COOL1,
   [SYSTEM_SWITCH_AUTO_ID] = SYSTEM_SWITCH_AUTO,
   [SYSTEM_SWITCH_OFF_ID] = SYSTEM_SWITCH_OFF,
}

-- HeatSetpoint
--   Degrees
HEAT_SETPOINT = "HeatSetpoint"

-- CoolSetpoint
--   Degrees
COOL_SETPOINT = "CoolSetpoint"

-- HeatNextPeriod
-- This is the time to hold the heat setpoint until. It is the number of 15 minute
-- intervals from midnight.
HEAT_NEXT = "HeatNextPeriod"

-- CoolNextPeriod
-- This is the time to hold the cool setpoint until. It is the number of 15 minute
-- intervals from midnight.
COOL_NEXT = "CoolNextPeriod"

-- Setpoint hold type
--   0 - cancel previous setpoint
--   1 - set setpoint
--   2 - set permanent hold
STATUS_TYPE_CANCEL_ID = 0
STATUS_TYPE_TEMP_ID = 1
STATUS_TYPE_TEMP = "Temporary"
STATUS_TYPE_PERM_ID = 2
STATUS_TYPE_PERM = "Permanent"
HOLD_TYPE_MAP = {
   [ STATUS_TYPE_TEMP ] = STATUS_TYPE_TEMP_ID,
   [ STATUS_TYPE_PERM ] = STATUS_TYPE_PERM_ID,
}
HOLD_TYPE_RMAP = {
   [ STATUS_TYPE_TEMP_ID ] = STATUS_TYPE_TEMP,
   [ STATUS_TYPE_PERM_ID ] = STATUS_TYPE_PERM,
}

-- StatusHeat
--   0 - cancel previous setpoint
--   1 - set setpoint
--   2 - set permanent hold
STATUS_HEAT = "StatusHeat"

-- StatusCool
--   0 - cancel previous setpoint
--   1 - set temporary hold
--   2 - set permanent hold
STATUS_COOL = "StatusCool"

-- FanMode
--   0 = Auto
--   1 = On (ContinuousOn)
--   2 = Circulate (PeriodicOn)
--   3 = FollowSchedule
FAN_MODE = "FanMode"
FAN_MODE_AUTO_ID = 0
FAN_MODE_AUTO = "Auto"
FAN_MODE_ON_ID = 1
FAN_MODE_ON = "ContinuousOn"
FAN_MODE_ON1 = "On"
FAN_MODE_PERIODIC_ID = 2
FAN_MODE_PERIODIC = "PeriodicOn"
FAN_MODE_PERIODIC1 = "Circulate"
FAN_MODE_SCHED_ID = 3
FAN_MODE_SCHED = "FollowSchedule"
FAN_MODE_MAP = {
   [FAN_MODE_AUTO] = FAN_MODE_AUTO_ID,
   [FAN_MODE_ON] = FAN_MODE_ON_ID,
   [FAN_MODE_PERIODIC] = FAN_MODE_PERIODIC_ID,
   [FAN_MODE_SCHED] = FAN_MODE_SCHED_ID,
}
FAN_MODE_RMAP = {
   [FAN_MODE_AUTO_ID] = FAN_MODE_AUTO,
   [FAN_MODE_ON_ID] = FAN_MODE_ON,
   [FAN_MODE_PERIODIC_ID] = FAN_MODE_PERIODIC,
   [FAN_MODE_SCHED_ID] = FAN_MODE_SCHED,
}
FAN_MODE_MAP1 = {
   [FAN_MODE_AUTO] = FAN_MODE_AUTO_ID,
   [FAN_MODE_ON1] = FAN_MODE_ON_ID,
   [FAN_MODE_PERIODIC1] = FAN_MODE_PERIODIC_ID,
   [FAN_MODE_SCHED] = FAN_MODE_SCHED_ID,
}
FAN_MODE_RMAP = {
   [FAN_MODE_AUTO_ID] = FAN_MODE_AUTO,
   [FAN_MODE_ON_ID] = FAN_MODE_ON1,
   [FAN_MODE_PERIODIC_ID] = FAN_MODE_PERIODIC1,
   [FAN_MODE_SCHED_ID] = FAN_MODE_SCHED,
}
